==> traccar_gennissi-0.0.12.tar.gz: lib/src/redux/viewModel.dart <==
import 'package:redux/redux.dart';
import 'package:traccar_gennissi/traccar_gennissi.dart';

import 'actions.dart';
import 'appstate.dart';

class ViewModel {
  final Map<int, PositionModel> positions;
  final Map<int, Device> devices;
  final Map<int, GeofenceModel> geofences;
  final PositionModel position;
  final List<Event> events;
  final Function(List<PositionModel>) updatePositions;
  final Function(List<Device>) updateDevices;
  final Function(List<GeofenceModel>) updateGeofences;
  final Function(PositionModel) updatePosition;
  final Function(List<Event>) addEvents;

  ViewModel(
      {this.positions,
      this.devices,
      this.position,
      this.geofences,
      this.events,
      this.updatePositions,
      this.updateDevices,
      this.updatePosition,
      this.updateGeofences,
      this.addEvents});

  factory ViewModel.create(Store<AppState> store) {
    _onUpdatePosition(List<PositionModel> positions) {
      store.dispatch(UpdatePositionAction(positions));
    }

    _onUpdateDevice(List<Device> devices) {
      store.dispatch(UpdateDeviceAction(devices));
    }

    // _onUpdateCurrentPosition(PositionModel pos) {
    //   store.dispatch(UpdateCurrentPositionAction(pos));
    // }

    _onUpdateGeofences(List<GeofenceModel> geofences) {
      store.dispatch(UpdateGeofenceAction(geofences));
    }

    _onAddEvents(List<Event> events) {
      store.dispatch(AddEventsAction(events));
    }

    return ViewModel(
        positions: store.state.positions,
        devices: store.state.devices,
        geofences: store.state.geofences,
        position: store.state.position,
        events: store.state.events,
        updatePositions: _onUpdatePosition,
        updateDevices: _onUpdateDevice,
        updateGeofences: _onUpdateGeofences,
        addEvents: _onAddEvents);
  }
}

==> traccar_gennissi-0.0.21.tar.gz: lib/src/redux/viewModel.dart <==
import 'package:redux/redux.dart';
import 'package:traccar_gennissi/traccar_gennissi.dart';

import 'actions.dart';
import 'appstate.dart';

class ViewModel {
  Map<int, PositionModel>? positions;
  Map<int, Device>? devices;
  Map<int, GeofenceModel>? geofences;
  PositionModel? position;
  List<Event>? events;
  Function(List<PositionModel>)? updatePositions;
  Function(List<Device>)? updateDevices;
  Function(List<GeofenceModel>)? updateGeofences;
  Function(PositionModel)? updatePosition;
  Function(List<Event>)? addEvents;

  ViewModel(
      {positions,
      devices,
      position,
      geofences,
      events,
      updatePositions,
      updateDevices,
      updatePosition,
      updateGeofences,
      addEvents});

  factory ViewModel.create(Store<AppState> store) {
    _onUpdatePosition(List<PositionModel> positions) {
      store.dispatch(UpdatePositionAction(positions));
    }

    _onUpdateDevice(List<Device> devices) {
      store.dispatch(UpdateDeviceAction(devices));
    }

    // _onUpdateCurrentPosition(PositionModel pos) {
    //   store.dispatch(UpdateCurrentPositionAction(pos));
    // }

    _onUpdateGeofences(List<GeofenceModel> geofences) {
      store.dispatch(UpdateGeofenceAction(geofences));
    }

    _onAddEvents(List<Event> events) {
      store.dispatch(AddEventsAction(events));
    }

    return ViewModel(
        positions: store.state.positions,
        devices: store.state.devices,
        geofences: store.state.geofences,
        position: store.state.position,
        events: store.state.events,
        updatePositions: _onUpdatePosition,
        updateDevices: _onUpdateDevice,
        updateGeofences: _onUpdateGeofences,
        addEvents: _onAddEvents);
  }
}
